@@ -22,6 +22,7 @@ import datetime
 import string
 import json
 import socket
+from fnmatch import fnmatch
 from collections import OrderedDict
 
 from pymongo import MongoClient
@@ -59,7 +60,6 @@ class VaspToDbTaskDrone(AbstractDrone):
     3. Directories containing vasp output with ".relax1" and ".relax2" are
        also considered as 2 parts of an aflow style run.
     """
-    vasprun_pattern = re.compile("^vasprun.xml([\w\.]*)")
 
     #Version of this db creator document.
     __version__ = "2.0.0"
@@ -155,8 +155,8 @@ class VaspToDbTaskDrone(AbstractDrone):
             #Materials project style aflow runs.
             for subtask in ["relax1", "relax2"]:
                 for f in os.listdir(os.path.join(path, subtask)):
-                    if VaspToDbTaskDrone.vasprun_pattern.match(f):
-                            vasprun_files[subtask] = os.path.join(subtask, f)
+                    if fnmatch(f, "vasprun.xml*"):
+                        vasprun_files[subtask] = os.path.join(subtask, f)
         elif "STOPCAR" in files:
             #Stopped runs. Try to parse as much as possible.
             logger.info(path + " contains stopped run")
@@ -164,12 +164,13 @@ class VaspToDbTaskDrone(AbstractDrone):
                 if subtask in files and \
                         os.path.isdir(os.path.join(path, subtask)):
                     for f in os.listdir(os.path.join(path, subtask)):
-                        if VaspToDbTaskDrone.vasprun_pattern.match(f):
+                        if fnmatch(f, "vasprun.xml*"):
                             vasprun_files[subtask] = os.path.join(
                                 subtask, f)
         else:
+            vasprun_pattern = re.compile("^vasprun.xml([\w\.]*)")
             for f in files:
-                m = VaspToDbTaskDrone.vasprun_pattern.match(f)
+                m = vasprun_pattern.match(f)
                 if m:
                     fileext = m.group(1)
                     if fileext.startswith(".relax2"):
@@ -340,7 +341,7 @@ class VaspToDbTaskDrone(AbstractDrone):
 
         for f in os.listdir(dir_name):
             filename = os.path.join(dir_name, f)
-            if re.match("INCAR.*", f):
+            if fnmatch(f, "INCAR*"):
                 try:
                     incar = Incar.from_file(filename)
                     d["incar"] = incar.to_dict
@@ -363,14 +364,14 @@ class VaspToDbTaskDrone(AbstractDrone):
                     print str(ex)
                     logger.error("Unable to parse INCAR for killed run {}."
                                  .format(dir_name))
-            elif re.match("KPOINTS.*", f):
+            elif fnmatch(f, "KPOINTS*"):
                 try:
                     kpoints = Kpoints.from_file(filename)
                     d["kpoints"] = kpoints.to_dict
                 except:
                     logger.error("Unable to parse KPOINTS for killed run {}."
                                  .format(dir_name))
-            elif re.match("POSCAR.*", f):
+            elif fnmatch(f, "POSCAR*"):
                 try:
                     s = Poscar.from_file(filename).structure
                     comp = s.composition
@@ -387,7 +388,7 @@ class VaspToDbTaskDrone(AbstractDrone):
                 except:
                     logger.error("Unable to parse POSCAR for killed run {}."
                                  .format(dir_name))
-            elif re.match("POTCAR.*", f):
+            elif fnmatch(f, "POTCAR*"):
                 try:
                     potcar = Potcar.from_file(filename)
                     d["pseudo_potential"] = {"functional": "pbe",
@@ -396,7 +397,7 @@ class VaspToDbTaskDrone(AbstractDrone):
                 except:
                     logger.error("Unable to parse POTCAR for killed run in {}."
                                  .format(dir_name))
-            elif re.match("OSZICAR", f):
+            elif fnmatch(f, "OSZICAR"):
                 try:
                     d["oszicar"]["root"] = \
                         Oszicar(os.path.join(dir_name, f)).to_dict
@@ -645,4 +646,4 @@ def get_uri(dir_name):
         hostname = socket.gethostbyaddr(socket.gethostname())[0]
     except:
         hostname = socket.gethostname()
-    return hostname + ":" + fullpath
+    return "{}:{}".format(hostname, fullpath)
